@@ -29,7 +29,7 @@ from snakemake.exceptions import (
 from snakemake.logging import logger
 from inspect import isfunction, ismethod
 
-from snakemake.common import DYNAMIC_FILL
+from snakemake.common import DYNAMIC_FILL, ON_WINDOWS
 
 
 def lutime(f, times):
@@ -808,7 +808,9 @@ def pipe(value):
         raise SyntaxError("Pipes may not be protected.")
     if is_flagged(value, "remote"):
         raise SyntaxError("Pipes may not be remote files.")
-    return flag(value, "pipe")
+    if ON_WINDOWS:
+        logger.warning("Pipes is not yet supported on Windows.")
+    return flag(value, "pipe", not ON_WINDOWS)
 
 
 def temporary(value):
@@ -970,13 +972,10 @@ def expand(*args, **wildcards):
 
 
 def multiext(prefix, *extensions):
-    """Expand a given prefix with multiple extensions (e.g. .txt, .csv, ...)."""
-    if any(
-        (r"/" in ext or r"\\" in ext or not ext.startswith(".")) for ext in extensions
-    ):
+    """Expand a given prefix with multiple extensions (e.g. .txt, .csv, _peaks.bed, ...)."""
+    if any((r"/" in ext or r"\\" in ext) for ext in extensions):
         raise WorkflowError(
-            r"Extensions for multiext may not contain path delimiters "
-            r"(/,\) and must start with '.' (e.g. .txt)."
+            r"Extensions for multiext may not contain path delimiters " r"(/,\)."
         )
     return [flag(prefix + ext, "multiext", flag_value=prefix) for ext in extensions]
 
