@@ -23,7 +23,7 @@ def parse_resources(resources_args, fallback=None):
     """Parse resources from args."""
     resources = dict()
     if resources_args is not None:
-        valid = re.compile("[a-zA-Z_]\w*$")
+        valid = re.compile(r"[a-zA-Z_]\w*$")
         for res in resources_args:
             try:
                 res, val = res.split("=")
