@@ -459,13 +459,13 @@ class PythonScript(ScriptBase):
         if self.conda_env is not None:
             prefix = os.path.join(self.conda_env, "bin")
         elif self.env_modules is not None:
-            prefix = self._execute_cmd("echo $PATH", read=True).decode().split(":")[0]
+            prefix = self._execute_cmd("echo $PATH", read=True).split(":")[0]
         else:
             raise NotImplementedError()
         return os.path.exists(os.path.join(prefix, "python"))
 
     def _get_python_version(self):
-        out = self._execute_cmd("python --version", read=True).decode().strip()
+        out = self._execute_cmd("python --version", read=True).strip()
         return tuple(map(int, PY_VER_RE.match(out).group("ver_min").split(".")))
 
     def execute_script(self, fname, edit=False):
